@@ -10,7 +10,8 @@ sub new
 {
     my $class = shift;
     $class->SUPER::new ( -value => 505,
-			 -text  => 'Invalid attribute value syntax' );
+			 -text  => 'Invalid attribute value syntax',
+                         -object=> shift );
 }
 
 1;
